@@ -1,5 +1,5 @@
 <?php
-/* Copyright (C) 2011-2012	Regis Houssin		<regis.houssin@capnetworks.com>
+/* Copyright (C) 2011-2022	Regis Houssin		<regis.houssin@inodbox.com>
  * Copyright (C) 2011-2012	Laurent Destailleur	<eldy@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,11 +13,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 /**
- *       \file       htdocs/core/ajax/fileupload.php
+ *       \file       htdocs/core/class/fileupload.class.php
  *       \brief      File to return Ajax response on file upload
  */
 
@@ -41,17 +41,24 @@ class FileUpload
 	 * @param int		$fk_element		fk_element
 	 * @param string	$element		element
 	 */
-	function __construct($options=null,$fk_element=null,$element=null)
+	public function __construct($options = null, $fk_element = null, $element = null)
 	{
 		global $db, $conf;
 		global $object;
+		global $hookmanager;
 
-		$this->fk_element=$fk_element;
-		$this->element=$element;
+		// Feature not enabled. Warning feature not used and not secured so disabled.
+		if (!getDolGlobalInt('MAIN_USE_JQUERY_FILEUPLOAD')) {
+			return;
+		}
 
-		$pathname=$filename=$element;
-		if (preg_match('/^([^_]+)_([^_]+)/i',$element,$regs))
-		{
+		$hookmanager->initHooks(array('fileupload'));
+
+		$this->fk_element = $fk_element;
+		$this->element = $element;
+
+		$pathname = $filename = $element;
+		if (preg_match('/^([^_]+)_([^_]+)/i', $element, $regs)) {
 			$pathname = $regs[1];
 			$filename = $regs[2];
 		}
@@ -61,48 +68,46 @@ class FileUpload
 		// For compatibility
 		if ($element == 'propal') {
 			$pathname = 'comm/propal';
-			$dir_output=$conf->$element->dir_output;
-		}
-		elseif ($element == 'facture') {
+			$dir_output = $conf->$element->dir_output;
+		} elseif ($element == 'facture') {
 			$pathname = 'compta/facture';
-			$dir_output=$conf->$element->dir_output;
-		}
-		elseif ($element == 'project') {
+			$dir_output = $conf->$element->dir_output;
+		} elseif ($element == 'project') {
 			$element = $pathname = 'projet';
-			$dir_output=$conf->$element->dir_output;
-		}
-		elseif ($element == 'project_task') {
-			$pathname = 'projet'; $filename='task';
-			$dir_output=$conf->projet->dir_output;
+			$dir_output = $conf->$element->dir_output;
+		} elseif ($element == 'project_task') {
+			$pathname = 'projet';
+			$filename = 'task';
+			$dir_output = $conf->project->dir_output;
 			$parentForeignKey = 'fk_project';
 			$parentClass = 'Project';
 			$parentElement = 'projet';
 			$parentObject = 'project';
-		}
-		elseif ($element == 'fichinter') {
-			$element='ficheinter';
-			$dir_output=$conf->$element->dir_output;
-		}
-		elseif ($element == 'order_supplier') {
-			$pathname = 'fourn'; $filename='fournisseur.commande';
-			$dir_output=$conf->fournisseur->commande->dir_output;
-		}
-		elseif ($element == 'invoice_supplier') {
-			$pathname = 'fourn'; $filename='fournisseur.facture';
-			$dir_output=$conf->fournisseur->facture->dir_output;
-		}
-		elseif ($element == 'product') {
+		} elseif ($element == 'fichinter') {
+			$element = 'ficheinter';
+			$dir_output = $conf->$element->dir_output;
+		} elseif ($element == 'order_supplier') {
+			$pathname = 'fourn';
+			$filename = 'fournisseur.commande';
+			$dir_output = $conf->fournisseur->commande->dir_output;
+		} elseif ($element == 'invoice_supplier') {
+			$pathname = 'fourn';
+			$filename = 'fournisseur.facture';
+			$dir_output = $conf->fournisseur->facture->dir_output;
+		} elseif ($element == 'product') {
 			$dir_output = $conf->product->multidir_output[$conf->entity];
-		}
-		elseif ($element == 'action') {
-			$pathname = 'comm/action'; $filename='actioncomm';
-			$dir_output=$conf->agenda->dir_output;
-		}
-		elseif ($element == 'chargesociales') {
-			$pathname = 'compta/sociales'; $filename='chargesociales';
-			$dir_output=$conf->tax->dir_output;
+		} elseif ($element == 'productbatch') {
+			$dir_output = $conf->productbatch->multidir_output[$conf->entity];
+		} elseif ($element == 'action') {
+			$pathname = 'comm/action';
+			$filename = 'actioncomm';
+			$dir_output = $conf->agenda->dir_output;
+		} elseif ($element == 'chargesociales') {
+			$pathname = 'compta/sociales';
+			$filename = 'chargesociales';
+			$dir_output = $conf->tax->dir_output;
 		} else {
-			$dir_output=$conf->$element->dir_output;
+			$dir_output = $conf->$element->dir_output;
 		}
 
 		dol_include_once('/'.$pathname.'/class/'.$filename.'.class.php');
@@ -132,14 +137,14 @@ class FileUpload
 
 		$object_ref = dol_sanitizeFileName($object->ref);
 		if ($element == 'invoice_supplier') {
-			$object_ref = get_exdir($object->id,2,0,0,$object,'invoice_supplier') . $object_ref;
-		} else if ($element == 'project_task') {
-			$object_ref = $object->project->ref . '/' . $object_ref;
+			$object_ref = get_exdir($object->id, 2, 0, 0, $object, 'invoice_supplier').$object_ref;
+		} elseif ($element == 'project_task') {
+			$object_ref = $object->project->ref.'/'.$object_ref;
 		}
 
 		$this->options = array(
 				'script_url' => $_SERVER['PHP_SELF'],
-				'upload_dir' => $dir_output . '/' . $object_ref . '/',
+				'upload_dir' => $dir_output.'/'.$object_ref.'/',
 				'upload_url' => DOL_URL_ROOT.'/document.php?modulepart='.$element.'&attachment=1&file=/'.$object_ref.'/',
 				'param_name' => 'files',
 				// Set the following option to 'POST', if your server does not support
@@ -173,13 +178,26 @@ class FileUpload
 		),
 		*/
 						'thumbnail' => array(
-								'upload_dir' => $dir_output . '/' . $object_ref . '/thumbs/',
+								'upload_dir' => $dir_output.'/'.$object_ref.'/thumbs/',
 								'upload_url' => DOL_URL_ROOT.'/document.php?modulepart='.$element.'&attachment=1&file=/'.$object_ref.'/thumbs/',
 								'max_width' => 80,
 								'max_height' => 80
 						)
 				)
 		);
+
+		global $action;
+
+		$hookmanager->executeHooks(
+			'overrideUploadOptions',
+			array(
+				'options' => &$options,
+				'element' => $element
+			),
+			$object,
+			$action
+		);
+
 		if ($options) {
 			$this->options = array_replace_recursive($this->options, $options);
 		}
@@ -199,19 +217,19 @@ class FileUpload
 		(isset($_SERVER['HTTP_HOST']) ? $_SERVER['HTTP_HOST'] : ($_SERVER['SERVER_NAME'].
 				($https && $_SERVER['SERVER_PORT'] === 443 ||
 						$_SERVER['SERVER_PORT'] === 80 ? '' : ':'.$_SERVER['SERVER_PORT']))).
-						substr($_SERVER['SCRIPT_NAME'],0, strrpos($_SERVER['SCRIPT_NAME'], '/'));
+						substr($_SERVER['SCRIPT_NAME'], 0, strrpos($_SERVER['SCRIPT_NAME'], '/'));
 	}
 
 	/**
 	 * Set delete url
 	 *
-	 * @param 	string	$file		Filename
+	 * @param 	object	$file		Filename
 	 * @return	void
 	 */
 	protected function setFileDeleteUrl($file)
 	{
 		$file->delete_url = $this->options['script_url']
-		.'?file='.rawurlencode($file->name).'&fk_element='.$this->fk_element.'&element='.$this->element;
+		.'?file='.urlencode($file->name).'&fk_element='.urlencode($this->fk_element).'&element='.urlencode($this->element);
 		$file->delete_type = $this->options['delete_type'];
 		if ($file->delete_type !== 'DELETE') {
 			$file->delete_url .= '&_method=DELETE';
@@ -222,21 +240,24 @@ class FileUpload
 	 * getFileObject
 	 *
 	 * @param	string		$file_name		Filename
-	 * @return 	stdClass|NULL
+	 * @return 	stdClass|null
 	 */
 	protected function getFileObject($file_name)
 	{
+		if (!getDolGlobalInt('MAIN_USE_JQUERY_FILEUPLOAD')) {
+			return;
+		}
+
 		$file_path = $this->options['upload_dir'].$file_name;
-		if (is_file($file_path) && $file_name[0] !== '.')
-		{
+		if (is_file($file_path) && $file_name[0] !== '.') {
 			$file = new stdClass();
 			$file->name = $file_name;
-			$file->mime = dol_mimetype($file_name,'',2);
+			$file->mime = dol_mimetype($file_name, '', 2);
 			$file->size = filesize($file_path);
 			$file->url = $this->options['upload_url'].rawurlencode($file->name);
-			foreach($this->options['image_versions'] as $version => $options) {
+			foreach ($this->options['image_versions'] as $version => $options) {
 				if (is_file($options['upload_dir'].$file_name)) {
-					$tmp=explode('.',$file->name);
+					$tmp = explode('.', $file->name);
 					$file->{$version.'_url'} = $options['upload_url'].rawurlencode($tmp[0].'_mini.'.$tmp[1]);
 				}
 			}
@@ -267,23 +288,26 @@ class FileUpload
 	{
 		global $maxwidthmini, $maxheightmini;
 
+		if (!getDolGlobalInt('MAIN_USE_JQUERY_FILEUPLOAD')) {
+			return;
+		}
+
 		$file_path = $this->options['upload_dir'].$file_name;
 		$new_file_path = $options['upload_dir'].$file_name;
 
-		if (dol_mkdir($options['upload_dir']) >= 0)
-		{
+		if (dol_mkdir($options['upload_dir']) >= 0) {
 			list($img_width, $img_height) = @getimagesize($file_path);
 			if (!$img_width || !$img_height) {
 				return false;
 			}
 
-			$res=vignette($file_path,$maxwidthmini,$maxheightmini,'_mini');  // We don't use ->addThumbs here because there is no object and we don't need all thumbs, only the "mini".
+			$res = vignette($file_path, $maxwidthmini, $maxheightmini, '_mini'); // We don't use ->addThumbs here because there is no object and we don't need all thumbs, only the "mini".
 
-			if (preg_match('/error/i',$res)) return false;
+			if (preg_match('/error/i', $res)) {
+				return false;
+			}
 			return true;
-		}
-		else
-		{
+		} else {
 			return false;
 		}
 	}
@@ -292,13 +316,17 @@ class FileUpload
 	 * Enter description here ...
 	 *
 	 * @param 	string	$uploaded_file		Uploade file
-	 * @param 	string	$file				File
+	 * @param 	object	$file				File
 	 * @param 	string	$error				Error
 	 * @param	string	$index				Index
 	 * @return  boolean                     True if OK, False if KO
 	 */
 	protected function validate($uploaded_file, $file, $error, $index)
 	{
+		if (!getDolGlobalInt('MAIN_USE_JQUERY_FILEUPLOAD')) {
+			return;
+		}
+
 		if ($error) {
 			$file->error = $error;
 			return false;
@@ -389,14 +417,12 @@ class FileUpload
 		// Also remove control characters and spaces (\x00..\x20) around the filename:
 		$file_name = trim(basename(stripslashes($name)), ".\x00..\x20");
 		// Add missing file extension for known image types:
-		if (strpos($file_name, '.') === false &&
-				preg_match('/^image\/(gif|jpe?g|png)/', $type, $matches)) {
+		$matches = array();
+		if (strpos($file_name, '.') === false && preg_match('/^image\/(gif|jpe?g|png)/', $type, $matches)) {
 			$file_name .= '.'.$matches[1];
 		}
-		if ($this->options['discard_aborted_uploads'])
-		{
-			while(is_file($this->options['upload_dir'].$file_name))
-			{
+		if ($this->options['discard_aborted_uploads']) {
+			while (is_file($this->options['upload_dir'].$file_name)) {
 				$file_name = $this->upcountName($file_name);
 			}
 		}
@@ -416,45 +442,40 @@ class FileUpload
 	 */
 	protected function handleFileUpload($uploaded_file, $name, $size, $type, $error, $index)
 	{
+		if (!getDolGlobalInt('MAIN_USE_JQUERY_FILEUPLOAD')) {
+			return;
+		}
+
 		$file = new stdClass();
 		$file->name = $this->trimFileName($name, $type, $index);
-		$file->mime = dol_mimetype($file->name,'',2);
+		$file->mime = dol_mimetype($file->name, '', 2);
 		$file->size = intval($size);
 		$file->type = $type;
-		if ($this->validate($uploaded_file, $file, $error, $index) && dol_mkdir($this->options['upload_dir']) >= 0)
-		{
+		if ($this->validate($uploaded_file, $file, $error, $index) && dol_mkdir($this->options['upload_dir']) >= 0) {
 			$file_path = $this->options['upload_dir'].$file->name;
 			$append_file = !$this->options['discard_aborted_uploads'] && is_file($file_path) && $file->size > filesize($file_path);
 			clearstatcache();
 			if ($uploaded_file && is_uploaded_file($uploaded_file)) {
 				// multipart/formdata uploads (POST method uploads)
-				if ($append_file)
-				{
+				if ($append_file) {
 					file_put_contents($file_path, fopen($uploaded_file, 'r'), FILE_APPEND);
 				} else {
 					dol_move_uploaded_file($uploaded_file, $file_path, 1, 0, 0, 0, 'userfile');
 				}
-			}
-			else
-			{
+			} else {
 				// Non-multipart uploads (PUT method support)
 				file_put_contents($file_path, fopen('php://input', 'r'), $append_file ? FILE_APPEND : 0);
 			}
 			$file_size = filesize($file_path);
-			if ($file_size === $file->size)
-			{
+			if ($file_size === $file->size) {
 				$file->url = $this->options['upload_url'].rawurlencode($file->name);
-				foreach($this->options['image_versions'] as $version => $options)
-				{
-					if ($this->createScaledImage($file->name, $options))
-					{
-						$tmp=explode('.',$file->name);
+				foreach ($this->options['image_versions'] as $version => $options) {
+					if ($this->createScaledImage($file->name, $options)) {
+						$tmp = explode('.', $file->name);
 						$file->{$version.'_url'} = $options['upload_url'].rawurlencode($tmp[0].'_mini.'.$tmp[1]);
 					}
 				}
-			}
-			else if ($this->options['discard_aborted_uploads'])
-			{
+			} elseif ($this->options['discard_aborted_uploads']) {
 				unlink($file_path);
 				$file->error = 'abort';
 			}
@@ -471,14 +492,15 @@ class FileUpload
 	 */
 	public function get()
 	{
+		if (!getDolGlobalInt('MAIN_USE_JQUERY_FILEUPLOAD')) {
+			return;
+		}
+
 		$file_name = isset($_REQUEST['file']) ?
 		basename(stripslashes($_REQUEST['file'])) : null;
-		if ($file_name)
-		{
+		if ($file_name) {
 			$info = $this->getFileObject($file_name);
-		}
-		else
-		{
+		} else {
 			$info = $this->getFileObjects();
 		}
 		header('Content-type: application/json');
@@ -492,38 +514,40 @@ class FileUpload
 	 */
 	public function post()
 	{
-		if (isset($_REQUEST['_method']) && $_REQUEST['_method'] === 'DELETE')
-		{
+		if (!getDolGlobalInt('MAIN_USE_JQUERY_FILEUPLOAD')) {
+			return;
+		}
+
+		if (isset($_REQUEST['_method']) && $_REQUEST['_method'] === 'DELETE') {
 			return $this->delete();
 		}
 		$upload = isset($_FILES[$this->options['param_name']]) ?
 		$_FILES[$this->options['param_name']] : null;
 		$info = array();
-		if ($upload && is_array($upload['tmp_name']))
-		{
+		if ($upload && is_array($upload['tmp_name'])) {
 			// param_name is an array identifier like "files[]",
 			// $_FILES is a multi-dimensional array:
 			foreach ($upload['tmp_name'] as $index => $value) {
-                $info[] = $this->handleFileUpload(
-                    $upload['tmp_name'][$index],
-                    isset($_SERVER['HTTP_X_FILE_NAME']) ? $_SERVER['HTTP_X_FILE_NAME'] : $upload['name'][$index],
-                    isset($_SERVER['HTTP_X_FILE_SIZE']) ? $_SERVER['HTTP_X_FILE_SIZE'] : $upload['size'][$index],
-                    isset($_SERVER['HTTP_X_FILE_TYPE']) ? $_SERVER['HTTP_X_FILE_TYPE'] : $upload['type'][$index],
-                    $upload['error'][$index],
-                    $index
-                );
+				$info[] = $this->handleFileUpload(
+					$upload['tmp_name'][$index],
+					isset($_SERVER['HTTP_X_FILE_NAME']) ? $_SERVER['HTTP_X_FILE_NAME'] : $upload['name'][$index],
+					isset($_SERVER['HTTP_X_FILE_SIZE']) ? $_SERVER['HTTP_X_FILE_SIZE'] : $upload['size'][$index],
+					isset($_SERVER['HTTP_X_FILE_TYPE']) ? $_SERVER['HTTP_X_FILE_TYPE'] : $upload['type'][$index],
+					$upload['error'][$index],
+					$index
+				);
 			}
 		} elseif ($upload || isset($_SERVER['HTTP_X_FILE_NAME'])) {
 			// param_name is a single object identifier like "file",
 			// $_FILES is a one-dimensional array:
-            $info[] = $this->handleFileUpload(
-                isset($upload['tmp_name']) ? $upload['tmp_name'] : null,
-                isset($_SERVER['HTTP_X_FILE_NAME']) ? $_SERVER['HTTP_X_FILE_NAME'] : (isset($upload['name']) ? $upload['name'] : null),
-                isset($_SERVER['HTTP_X_FILE_SIZE']) ? $_SERVER['HTTP_X_FILE_SIZE'] : (isset($upload['size']) ? $upload['size'] : null),
-                isset($_SERVER['HTTP_X_FILE_TYPE']) ? $_SERVER['HTTP_X_FILE_TYPE'] : (isset($upload['type']) ? $upload['type'] : null),
-                isset($upload['error']) ? $upload['error'] : null,
-                0
-            );
+			$info[] = $this->handleFileUpload(
+				isset($upload['tmp_name']) ? $upload['tmp_name'] : null,
+				isset($_SERVER['HTTP_X_FILE_NAME']) ? $_SERVER['HTTP_X_FILE_NAME'] : (isset($upload['name']) ? $upload['name'] : null),
+				isset($_SERVER['HTTP_X_FILE_SIZE']) ? $_SERVER['HTTP_X_FILE_SIZE'] : (isset($upload['size']) ? $upload['size'] : null),
+				isset($_SERVER['HTTP_X_FILE_TYPE']) ? $_SERVER['HTTP_X_FILE_TYPE'] : (isset($upload['type']) ? $upload['type'] : null),
+				isset($upload['error']) ? $upload['error'] : null,
+				0
+			);
 		}
 		header('Vary: Accept');
 		$json = json_encode($info);
@@ -545,21 +569,22 @@ class FileUpload
 	/**
 	 * Delete uploaded file
 	 *
-	 * @return	void
+	 * @return	string
 	 */
 	public function delete()
 	{
+		if (!getDolGlobalInt('MAIN_USE_JQUERY_FILEUPLOAD')) {
+			return;
+		}
+
 		$file_name = isset($_REQUEST['file']) ?
 		basename(stripslashes($_REQUEST['file'])) : null;
 		$file_path = $this->options['upload_dir'].$file_name;
 		$success = is_file($file_path) && $file_name[0] !== '.' && unlink($file_path);
-		if ($success)
-		{
-			foreach($this->options['image_versions'] as $version => $options)
-			{
+		if ($success) {
+			foreach ($this->options['image_versions'] as $version => $options) {
 				$file = $options['upload_dir'].$file_name;
-				if (is_file($file))
-				{
+				if (is_file($file)) {
 					unlink($file);
 				}
 			}
